@@ -3,12 +3,13 @@ from .cli_ditask import cli_ditask
 from .serial_entry import serial_pipeline
 from .serial_entry_td3_vae import serial_pipeline_td3_vae
 from .serial_entry_onpolicy import serial_pipeline_onpolicy
+from .serial_entry_onpolicy_ppg import serial_pipeline_onpolicy_ppg
 from .serial_entry_offline import serial_pipeline_offline
 from .serial_entry_ngu import serial_pipeline_ngu
+from .serial_entry_decision_transformer import serial_pipeline_dt
 from .serial_entry_reward_model_offpolicy import serial_pipeline_reward_model_offpolicy
 from .serial_entry_reward_model_onpolicy import serial_pipeline_reward_model_onpolicy
 from .serial_entry_bc import serial_pipeline_bc
-from .serial_entry_mbrl import serial_pipeline_mbrl
 from .serial_entry_dqfd import serial_pipeline_dqfd
 from .serial_entry_r2d3 import serial_pipeline_r2d3
 from .serial_entry_sqil import serial_pipeline_sqil
@@ -24,3 +25,4 @@ from .serial_entry_preference_based_irl \
 from .serial_entry_preference_based_irl_onpolicy \
       import serial_pipeline_preference_based_irl_onpolicy
 from .application_entry_drex_collect_data import drex_collecting_data
+from .serial_entry_mbrl import serial_pipeline_dyna, serial_pipeline_dream
