@@ -67,7 +67,6 @@ class DingEnvWrapper(BaseEnv):
             self._env.seed(self._seed)
         obs = self._env.reset()
         obs = to_ndarray(obs).astype(np.float32)
-        self._action_type = self._cfg.get('action_type', 'scalar')
         return obs
 
     # override
@@ -81,7 +80,7 @@ class DingEnvWrapper(BaseEnv):
         np.random.seed(self._seed)
 
     # override
-    def step(self, action: np.ndarray) -> BaseEnvTimestep:
+    def step(self, action: Union[np.int64, np.ndarray]) -> BaseEnvTimestep:
         action = self._judge_action_type(action)
         if self._cfg.get('act_scale', False):
             action = affine_transform(action, min_val=self._env.action_space.low, max_val=self._env.action_space.high)
@@ -94,7 +93,7 @@ class DingEnvWrapper(BaseEnv):
         if isinstance(action, int):
             return action
         if isinstance(action, np.ndarray):
-            if action.shape == (1, ) and self._action_type == 'scalar':
+            if action.shape == (1, ) and action.dtype == np.int64:
                 action = action.item()
             return action
         elif isinstance(action, dict):
