@@ -1,18 +1,16 @@
 from types import MethodType
-from typing import Tuple, Union, Any, List, Callable, Dict, Optional
+from typing import Union, Any, List, Callable, Dict, Optional, Tuple
 from functools import partial, wraps
 from easydict import EasyDict
 import copy
 import platform
-from collections import namedtuple
 import numbers
-import logging
+from ditk import logging
 import enum
 import time
-
-from ding.utils import ENV_MANAGER_REGISTRY, import_module, one_time_warning
-from ding.envs.env.base_env import BaseEnvTimestep
-from ding.utils.time_helper import WatchDog
+import treetensor.numpy as tnp
+from ding.utils import ENV_MANAGER_REGISTRY, import_module, one_time_warning, make_key_as_identifier, WatchDog
+from ding.envs.env import BaseEnvTimestep
 
 
 class EnvState(enum.IntEnum):
@@ -126,6 +124,10 @@ class BaseEnvManager(object):
     def env_num(self) -> int:
         return self._env_num
 
+    @property
+    def env_ref(self) -> int:
+        return self._env_ref
+
     @property
     def observation_space(self) -> 'gym.spaces.Space':  # noqa
         return self._observation_space
@@ -142,23 +144,43 @@ class BaseEnvManager(object):
     def ready_obs(self) -> Dict[int, Any]:
         """
         Overview:
-            Get the next observations(in ``np.ndarray`` type) and corresponding env id.
+            Get the ready (next) observation, which is uniform for both aysnc/sync scenarios.
         Return:
-            A dictionary with observations and their environment IDs.
+            - ready_obs (:obj:`Dict[int, Any]:`): Dict with env_id keys and observation values.
         Example:
-            >>>     obs_dict = env_manager.ready_obs
-            >>>     actions_dict = {env_id: model.forward(obs) for env_id, obs in obs_dict.items())}
+            >>> obs = env_manager.ready_obs
+            >>> stacked_obs = np.concatenate(list(obs.values()))
+            >>> action = model(obs)  # model input np obs and output np action
+            >>> action = {env_id: a for env_id, a in zip(obs.keys(), action)}
+            >>> timesteps = env_manager.step(action)
         """
         active_env = [i for i, s in self._env_states.items() if s == EnvState.RUN]
         return {i: self._ready_obs[i] for i in active_env}
 
+    @property
+    def ready_obs_id(self) -> List[int]:
+        # In BaseEnvManager, if env_episode_count equals episode_num, this env is done.
+        return [i for i, s in self._env_states.items() if s == EnvState.RUN]
+
+    @property
+    def ready_imgs(self, render_mode: Optional[str] = 'rgb_array') -> Dict[int, Any]:
+        """
+        Overview:
+            Get the next ready renderd frame and corresponding env id.
+        Return:
+            - ready_imgs (:obj:`Dict[int, np.ndarray]:`): Dict with env_id keys and rendered frames.
+        """
+        from ding.utils import render
+        assert render_mode in ['rgb_array', 'depth_array']
+        return {i: render(self._envs[i], render_mode) for i in self.ready_obs.keys()}
+
     @property
     def done(self) -> bool:
         return all([s == EnvState.DONE for s in self._env_states.values()])
 
     @property
     def method_name_list(self) -> list:
-        return ['reset', 'step', 'seed', 'close', 'enable_save_replay']
+        return ['reset', 'step', 'seed', 'close', 'enable_save_replay', 'render']
 
     def env_state_done(self, env_id: int) -> bool:
         return self._env_states[env_id] == EnvState.DONE
@@ -280,25 +302,20 @@ class BaseEnvManager(object):
         runtime_error.__traceback__ = exceptions[-1].__traceback__
         raise runtime_error
 
-    def step(self, actions: Dict[int, Any]) -> Dict[int, namedtuple]:
+    def step(self, actions: Dict[int, Any]) -> List[Dict[int, BaseEnvTimestep]]:
         """
         Overview:
-            Step all environments. Reset an env if done.
+            Execute env step according to input actions. And reset an env if done.
         Arguments:
-            - actions (:obj:`Dict[int, Any]`): {env_id: action}
+            - actions (:obj:`Dict[int, Any]`): actions came from outer caller like policy
         Returns:
-            - timesteps (:obj:`Dict[int, namedtuple]`): {env_id: timestep}. Timestep is a \
-                ``BaseEnvTimestep`` tuple with observation, reward, done, env_info.
+            - timesteps (:obj:`List[Dict[int, BaseEnvTimestep]]`): Each timestep is a BaseEnvTimestep object, \
+                usually including observation, reward, done, info.
         Example:
-            >>>     actions_dict = {env_id: model.forward(obs) for env_id, obs in obs_dict.items())}
-            >>>     timesteps = env_manager.step(actions_dict):
-            >>>     for env_id, timestep in timesteps.items():
-            >>>         pass
-
-        .. note:
-
-            - The env_id that appears in ``actions`` will also be returned in ``timesteps``.
-            - Once an environment is done, it is reset immediately.
+            >>> timesteps = env_manager.step(action)
+            >>> for i, timestep in enumerate(timesteps):
+            >>>     if timestep.done:
+            >>>         print('Env {} is done'.format(timestep.env_id))
         """
         self._check_closed()
         timesteps = {}
@@ -317,7 +334,7 @@ class BaseEnvManager(object):
                 self._ready_obs[env_id] = timesteps[env_id].obs
         return timesteps
 
-    def _step(self, env_id: int, act: Any) -> namedtuple:
+    def _step(self, env_id: int, act: Any) -> BaseEnvTimestep:
 
         @timeout_wrapper(timeout=self._step_timeout)
         def step_fn():
@@ -387,6 +404,55 @@ class BaseEnvManager(object):
             self._env_states[i] = EnvState.VOID
         self._closed = True
 
+    @property
+    def closed(self) -> bool:
+        return self._closed
+
+
+@ENV_MANAGER_REGISTRY.register('base_v2')
+class BaseEnvManagerV2(BaseEnvManager):
+    """
+    Overview:
+        BaseEnvManager for new task pipeline and interfaces coupled with treetensor.
+    """
+
+    @property
+    def ready_obs(self) -> tnp.array:
+        """
+        Overview:
+            Get the ready (next) observation in ``tnp.array`` type, which is uniform for both async/sync scenarios.
+        Return:
+            - ready_obs (:obj:`tnp.array`): A stacked treenumpy-type observation data.
+        Example:
+            >>> obs = env_manager.ready_obs
+            >>> action = model(obs)  # model input np obs and output np action
+            >>> timesteps = env_manager.step(action)
+        """
+        active_env = [i for i, s in self._env_states.items() if s == EnvState.RUN]
+        obs = [self._ready_obs[i] for i in active_env]
+        return tnp.stack(obs)
+
+    def step(self, actions: List[tnp.ndarray]) -> List[tnp.ndarray]:
+        """
+        Overview:
+            Execute env step according to input actions. And reset an env if done.
+        Arguments:
+            - actions (:obj:`List[tnp.ndarray]`): actions came from outer caller like policy
+        Returns:
+            - timesteps (:obj:`List[tnp.ndarray]`): Each timestep is a tnp.array with observation, reward, done, \
+                info, env_id.
+        """
+        actions = {env_id: a for env_id, a in zip(self.ready_obs_id, actions)}
+        timesteps = super().step(actions)
+        new_data = []
+        for env_id, timestep in timesteps.items():
+            obs, reward, done, info = timestep
+            # make the type and content of key as similar as identifier,
+            # in order to call them as attribute (e.g. timestep.xxx), such as ``TimeLimit.truncated`` in cartpole info
+            info = make_key_as_identifier(info)
+            new_data.append(tnp.array({'obs': obs, 'reward': reward, 'done': done, 'info': info, 'env_id': env_id}))
+        return new_data
+
 
 def create_env_manager(manager_cfg: dict, env_fn: List[Callable]) -> BaseEnvManager:
     r"""
