@@ -926,6 +926,76 @@ class GymHybridDictActionWrapper(gym.ActionWrapper):
     #     return (size, size), act_shape, rew_shape
 
 
+@ENV_WRAPPER_REGISTRY.register('obs_plus_prev_action_reward')
+class ObsPlusPrevActRewWrapper(gym.Wrapper):
+    """
+    Overview:
+       This wrapper is used in policy NGU.
+       Set a dict {'obs': obs, 'prev_action': self.prev_action, 'prev_reward_extrinsic': self.prev_reward_extrinsic}
+       as the new wrapped observation,
+       which including the current obs, previous action and previous reward.
+    Interface:
+        ``__init__``, ``reset``, ``step``
+    Properties:
+        - env (:obj:`gym.Env`): the environment to wrap.
+    """
+
+    def __init__(self, env):
+        """
+        Overview:
+            Initialize ``self.`` See ``help(type(self))`` for accurate signature; setup the properties.
+        Arguments:
+            - env (:obj:`gym.Env`): the environment to wrap.
+        """
+        super().__init__(env)
+        self.observation_space = gym.spaces.Dict(
+            {
+                'obs': env.observation_space,
+                'prev_action': env.action_space,
+                'prev_reward_extrinsic': gym.spaces.Box(
+                    low=env.reward_range[0], high=env.reward_range[1], shape=(1, ), dtype=np.float32
+                )
+            }
+        )
+        self.prev_action = -1  # null action
+        self.prev_reward_extrinsic = 0  # null reward
+
+    def reset(self):
+        """
+        Overview:
+            Resets the state of the environment.
+        Returns:
+            -  obs (:obj:`Dict`) : the wrapped observation, which including the current obs, \
+                previous action and previous reward.
+        """
+        obs = self.env.reset()
+        obs = {'obs': obs, 'prev_action': self.prev_action, 'prev_reward_extrinsic': self.prev_reward_extrinsic}
+        return obs
+
+    def step(self, action):
+        """
+        Overview:
+            Step the environment with the given action.
+            Save the previous action and reward to be used in next new obs
+        Arguments:
+            - action (:obj:`Any`): the given action to step with.
+        Returns:
+            -  obs (:obj:`Dict`) : the wrapped observation, which including the current obs, \
+                previous action and previous reward.
+            - reward (:obj:`Any`) : amount of reward returned after previous action
+            - done (:obj:`Bool`) : whether the episode has ended, in which case further \
+                 step() calls will return undefined results
+            - info (:obj:`Dict`) : contains auxiliary diagnostic information (helpful  \
+                for debugging, and sometimes learning)
+        """
+
+        obs, reward, done, info = self.env.step(action)
+        obs = {'obs': obs, 'prev_action': self.prev_action, 'prev_reward_extrinsic': self.prev_reward_extrinsic}
+        self.prev_action = action
+        self.prev_reward_extrinsic = reward
+        return obs, reward, done, info
+
+
 def update_shape(obs_shape, act_shape, rew_shape, wrapper_names):
     """
     Overview:
