@@ -83,7 +83,7 @@ class R2D3Policy(Policy):
         burnin_step=2,
         # (int) the trajectory length to unroll the RNN network minus
         # the timestep of burnin operation
-        unroll_len=80,
+        learn_unroll_len=80,
         learn=dict(
             # (bool) Whether to use multi gpu
             multi_gpu=False,
@@ -205,25 +205,25 @@ class R2D3Policy(Policy):
         bs = self._burnin_step
 
         # data['done'], data['weight'], data['value_gamma'] is used in def _forward_learn() to calculate
-        # the q_nstep_td_error, should be length of [self._unroll_len_add_burnin_step-self._burnin_step-self._nstep]
+        # the q_nstep_td_error, should be length of [self._sequence_len-self._burnin_step-self._nstep]
         ignore_done = self._cfg.learn.ignore_done
         if ignore_done:
-            data['done'] = [None for _ in range(self._unroll_len_add_burnin_step - bs)]
+            data['done'] = [None for _ in range(self._sequence_len - bs)]
         else:
             data['done'] = data['done'][bs:].float()
             # NOTE that after the proprocessing of  get_nstep_return_data() in _get_train_sample
             # the data['done'] [t] is already the n-step done
 
         # if the data don't include 'weight' or 'value_gamma' then fill in None in a list
-        # with length of [self._unroll_len_add_burnin_step-self._burnin_step-self._nstep],
+        # with length of [self._sequence_len-self._burnin_step-self._nstep],
         # below is two different implementation ways
         if 'value_gamma' not in data:
-            data['value_gamma'] = [None for _ in range(self._unroll_len_add_burnin_step - bs)]
+            data['value_gamma'] = [None for _ in range(self._sequence_len - bs)]
         else:
             data['value_gamma'] = data['value_gamma'][bs:]
 
         if 'weight' not in data:
-            data['weight'] = [None for _ in range(self._unroll_len_add_burnin_step - bs)]
+            data['weight'] = [None for _ in range(self._sequence_len - bs)]
         else:
             data['weight'] = data['weight'] * torch.ones_like(data['done'])
             # every timestep in sequence has same weight, which is the _priority_IS_weight in PER
@@ -235,7 +235,7 @@ class R2D3Policy(Policy):
         # target_q_value, and target_q_action
         data['burnin_nstep_obs'] = data['obs'][:bs + self._nstep]
         # the main_obs is used to calculate the q_value, the [bs:-self._nstep] means using the data from
-        # [bs] timestep to [self._unroll_len_add_burnin_step-self._nstep] timestep
+        # [bs] timestep to [self._sequence_len-self._nstep] timestep
         data['main_obs'] = data['obs'][bs:-self._nstep]
         # the target_obs is used to calculate the target_q_value
         data['target_obs'] = data['obs'][bs + self._nstep:]
@@ -243,7 +243,7 @@ class R2D3Policy(Policy):
         # TODO(pu)
         data['target_obs_one_step'] = data['obs'][bs + 1:]
         if ignore_done:
-            data['done_one_step'] = [None for _ in range(self._unroll_len_add_burnin_step - bs)]
+            data['done_one_step'] = [None for _ in range(self._sequence_len - bs)]
         else:
             data['done_one_step'] = data['done_one_step'][bs:].float()
 
@@ -277,24 +277,20 @@ class R2D3Policy(Policy):
                 inputs = {'obs': data['burnin_nstep_obs'], 'enable_fast_timestep': True}
                 burnin_output = self._learn_model.forward(
                     inputs,
-                    saved_hidden_state_timesteps=[
-                        self._burnin_step, self._burnin_step + self._nstep, self._burnin_step + 1
-                    ]
+                    saved_state_timesteps=[self._burnin_step, self._burnin_step + self._nstep, self._burnin_step + 1]
                 )
                 burnin_output_target = self._target_model.forward(
                     inputs,
-                    saved_hidden_state_timesteps=[
-                        self._burnin_step, self._burnin_step + self._nstep, self._burnin_step + 1
-                    ]
+                    saved_state_timesteps=[self._burnin_step, self._burnin_step + self._nstep, self._burnin_step + 1]
                 )
 
-        self._learn_model.reset(data_id=None, state=burnin_output['saved_hidden_state'][0])
+        self._learn_model.reset(data_id=None, state=burnin_output['saved_state'][0])
         inputs = {'obs': data['main_obs'], 'enable_fast_timestep': True}
         q_value = self._learn_model.forward(inputs)['logit']
 
         # n-step
-        self._learn_model.reset(data_id=None, state=burnin_output['saved_hidden_state'][1])
-        self._target_model.reset(data_id=None, state=burnin_output_target['saved_hidden_state'][1])
+        self._learn_model.reset(data_id=None, state=burnin_output['saved_state'][1])
+        self._target_model.reset(data_id=None, state=burnin_output_target['saved_state'][1])
 
         next_inputs = {'obs': data['target_obs'], 'enable_fast_timestep': True}
         with torch.no_grad():
@@ -303,8 +299,8 @@ class R2D3Policy(Policy):
             target_q_action = self._learn_model.forward(next_inputs)['action']
 
         # one-step
-        self._learn_model.reset(data_id=None, state=burnin_output['saved_hidden_state'][2])
-        self._target_model.reset(data_id=None, state=burnin_output_target['saved_hidden_state'][2])
+        self._learn_model.reset(data_id=None, state=burnin_output['saved_state'][2])
+        self._target_model.reset(data_id=None, state=burnin_output_target['saved_state'][2])
 
         next_inputs_one_step = {'obs': data['target_obs_one_step'], 'enable_fast_timestep': True}
         with torch.no_grad():
@@ -322,7 +318,7 @@ class R2D3Policy(Policy):
         loss_1step = []
         loss_sl = []
         td_error = []
-        for t in range(self._unroll_len_add_burnin_step - self._burnin_step - self._nstep):
+        for t in range(self._sequence_len - self._burnin_step - self._nstep):
             # here t=0 means timestep <self._burnin_step> in the original sample sequence, we minus self._nstep
             # because for the last <self._nstep> timestep in the sequence, we don't have their target obs
             td_data = dqfd_nstep_td_data(
@@ -389,7 +385,7 @@ class R2D3Policy(Policy):
         td_error_per_sample = 0.9 * torch.max(
             torch.stack(td_error), dim=0
         )[0] + (1 - 0.9) * (torch.sum(torch.stack(td_error), dim=0) / (len(td_error) + 1e-8))
-        # td_error shape list(<self._unroll_len_add_burnin_step-self._burnin_step-self._nstep>, B), for example, (75,64)
+        # td_error shape list(<self._sequence_len-self._burnin_step-self._nstep>, B), for example, (75,64)
         # torch.sum(torch.stack(td_error), dim=0) can also be replaced with sum(td_error)
 
         # update
@@ -443,8 +439,8 @@ class R2D3Policy(Policy):
         self._nstep = self._cfg.nstep
         self._burnin_step = self._cfg.burnin_step
         self._gamma = self._cfg.discount_factor
-        self._unroll_len_add_burnin_step = self._cfg.unroll_len + self._cfg.burnin_step
-        self._unroll_len = self._unroll_len_add_burnin_step  # for compatibility
+        self._sequence_len = self._cfg.learn_unroll_len + self._cfg.burnin_step
+        self._unroll_len = self._sequence_len  # for compatibility
 
         self._collect_model = model_wrap(
             self._model, wrapper_name='hidden_state', state_num=self._cfg.collect.env_num, save_prev_state=True
@@ -520,7 +516,7 @@ class R2D3Policy(Policy):
             # here we record the one-step done, we don't need record one-step reward,
             # because the n-step reward in data already include one-step reward
             data[i]['done_one_step'] = data_one_step[i]['done']
-        return get_train_sample(data, self._unroll_len_add_burnin_step)
+        return get_train_sample(data, self._sequence_len)
 
     def _init_eval(self) -> None:
         r"""
