@@ -3,6 +3,7 @@ from collections import namedtuple
 import copy
 import numpy as np
 import torch
+import torch.nn as nn
 import torch.nn.functional as F
 from torch.distributions import Normal, Independent
 
@@ -76,7 +77,6 @@ class SACDiscretePolicy(Policy):
         # on-policy setting influences the behaviour of buffer.
         # Default False in SAC.
         on_policy=False,
-        multi_agent=True,
         # (bool type) priority: Determine whether to use priority in buffer sample.
         # Default False in SAC.
         priority=False,
@@ -85,6 +85,10 @@ class SACDiscretePolicy(Policy):
         # (int) Number of training samples(randomly collected) in replay buffer when training starts.
         # Default 10000 in SAC.
         random_collect_size=10000,
+        # (bool) Whether to need policy data in process transition
+        transition_with_policy_data=True,
+        # (bool) Whether to enable multi-agent training setting
+        multi_agent=True,
         model=dict(
             # (bool type) twin_critic: Determine whether to use double-soft-q-net for target q computation.
             # Please refer to TD3 about Clipped Double-Q Learning trick, which learns two Q-functions instead of one .
@@ -586,6 +590,9 @@ class SACPolicy(Policy):
         # (int) Number of training samples(randomly collected) in replay buffer when training starts.
         # Default 10000 in SAC.
         random_collect_size=10000,
+        # (bool) Whether to need policy data in process transition
+        transition_with_policy_data=True,
+        # (bool) Whether to enable multi-agent training setting
         multi_agent=False,
         model=dict(
             # (bool type) twin_critic: Determine whether to use double-soft-q-net for target q computation.
@@ -1073,3 +1080,516 @@ class SACPolicy(Policy):
             'alpha',
             'td_error',
         ] + twin_critic + alpha_loss + value_loss
+
+
+@POLICY_REGISTRY.register('sqil_sac')
+class SQILSACPolicy(SACPolicy):
+    r"""
+       Overview:
+           Policy class of continuous SAC algorithm.
+
+           https://arxiv.org/pdf/1801.01290.pdf
+
+       Config:
+           == ====================  ========    =============  ================================= =======================
+           ID Symbol                Type        Default Value  Description                       Other(Shape)
+           == ====================  ========    =============  ================================= =======================
+           1  ``type``              str         td3            | RL policy register name, refer  | this arg is optional,
+                                                               | to registry ``POLICY_REGISTRY`` | a placeholder
+           2  ``cuda``              bool        True           | Whether to use cuda for network |
+           3  | ``random_``         int         10000          | Number of randomly collected    | Default to 10000 for
+              | ``collect_size``                               | training samples in replay      | SAC, 25000 for DDPG/
+              |                                                | buffer when training starts.    | TD3.
+           4  | ``model.policy_``   int         256            | Linear layer size for policy    |
+              | ``embedding_size``                             | network.                        |
+           5  | ``model.soft_q_``   int         256            | Linear layer size for soft q    |
+              | ``embedding_size``                             | network.                        |
+           6  | ``model.value_``    int         256            | Linear layer size for value     | Defalut to None when
+              | ``embedding_size``                             | network.                        | model.value_network
+              |                                                |                                 | is False.
+           7  | ``learn.learning``  float       3e-4           | Learning rate for soft q        | Defalut to 1e-3, when
+              | ``_rate_q``                                    | network.                        | model.value_network
+              |                                                |                                 | is True.
+           8  | ``learn.learning``  float       3e-4           | Learning rate for policy        | Defalut to 1e-3, when
+              | ``_rate_policy``                               | network.                        | model.value_network
+              |                                                |                                 | is True.
+           9  | ``learn.learning``  float       3e-4           | Learning rate for policy        | Defalut to None when
+              | ``_rate_value``                                | network.                        | model.value_network
+              |                                                |                                 | is False.
+           10 | ``learn.alpha``     float       0.2            | Entropy regularization          | alpha is initiali-
+              |                                                | coefficient.                    | zation for auto
+              |                                                |                                 | `\alpha`, when
+              |                                                |                                 | auto_alpha is True
+           11 | ``learn.repara_``   bool        True           | Determine whether to use        |
+              | ``meterization``                               | reparameterization trick.       |
+           12 | ``learn.``          bool        False          | Determine whether to use        | Temperature parameter
+              | ``auto_alpha``                                 | auto temperature parameter      | determines the
+              |                                                | `\alpha`.                       | relative importance
+              |                                                |                                 | of the entropy term
+              |                                                |                                 | against the reward.
+           13 | ``learn.-``         bool        False          | Determine whether to ignore     | Use ignore_done only
+              | ``ignore_done``                                | done flag.                      | in halfcheetah env.
+           14 | ``learn.-``         float       0.005          | Used for soft update of the     | aka. Interpolation
+              | ``target_theta``                               | target network.                 | factor in polyak aver
+              |                                                |                                 | aging for target
+              |                                                |                                 | networks.
+           == ====================  ========    =============  ================================= =======================
+       """
+
+    config = dict(
+        # (str) RL policy register name (refer to function "POLICY_REGISTRY").
+        type='sqil_sac',
+        # (bool) Whether to use cuda for network.
+        cuda=False,
+        # (bool type) on_policy: Determine whether on-policy or off-policy.
+        # on-policy setting influences the behaviour of buffer.
+        # Default False in SAC.
+        on_policy=False,
+        # (bool type) priority: Determine whether to use priority in buffer sample.
+        # Default False in SAC.
+        priority=False,
+        # (bool) Whether use Importance Sampling Weight to correct biased update. If True, priority must be True.
+        priority_IS_weight=False,
+        # (int) Number of training samples(randomly collected) in replay buffer when training starts.
+        # Default 10000 in SAC.
+        random_collect_size=10000,
+        # (bool) Whether to need policy data in process transition
+        transition_with_policy_data=True,
+        # (bool) Whether to enable multi-agent training setting
+        multi_agent=False,
+        model=dict(
+            # (bool type) twin_critic: Determine whether to use double-soft-q-net for target q computation.
+            # Please refer to TD3 about Clipped Double-Q Learning trick, which learns two Q-functions instead of one .
+            # Default to True.
+            twin_critic=True,
+
+            # (bool type) value_network: Determine whether to use value network as the
+            # original SAC paper (arXiv 1801.01290).
+            # using value_network needs to set learning_rate_value, learning_rate_q,
+            # and learning_rate_policy in `cfg.policy.learn`.
+            # Default to False.
+            # value_network=False,
+
+            # (str type) action_space: Use reparameterization trick for continous action
+            action_space='reparameterization',
+        ),
+        learn=dict(
+            # (bool) Whether to use multi gpu
+            multi_gpu=False,
+            # How many updates(iterations) to train after collector's one collection.
+            # Bigger "update_per_collect" means bigger off-policy.
+            # collect data -> update policy-> collect data -> ...
+            update_per_collect=1,
+            # (int) Minibatch size for gradient descent.
+            batch_size=256,
+
+            # (float type) learning_rate_q: Learning rate for soft q network.
+            # Default to 3e-4.
+            # Please set to 1e-3, when model.value_network is True.
+            learning_rate_q=3e-4,
+            # (float type) learning_rate_policy: Learning rate for policy network.
+            # Default to 3e-4.
+            # Please set to 1e-3, when model.value_network is True.
+            learning_rate_policy=3e-4,
+            # (float type) learning_rate_value: Learning rate for value network.
+            # `learning_rate_value` should be initialized, when model.value_network is True.
+            # Please set to 3e-4, when model.value_network is True.
+            learning_rate_value=3e-4,
+
+            # (float type) learning_rate_alpha: Learning rate for auto temperature parameter `\alpha`.
+            # Default to 3e-4.
+            learning_rate_alpha=3e-4,
+            # (float type) target_theta: Used for soft update of the target network,
+            # aka. Interpolation factor in polyak averaging for target networks.
+            # Default to 0.005.
+            target_theta=0.005,
+            # (float) discount factor for the discounted sum of rewards, aka. gamma.
+            discount_factor=0.99,
+
+            # (float type) alpha: Entropy regularization coefficient.
+            # Please check out the original SAC paper (arXiv 1801.01290): Eq 1 for more details.
+            # If auto_alpha is set  to `True`, alpha is initialization for auto `\alpha`.
+            # Default to 0.2.
+            alpha=0.2,
+
+            # (bool type) auto_alpha: Determine whether to use auto temperature parameter `\alpha` .
+            # Temperature parameter determines the relative importance of the entropy term against the reward.
+            # Please check out the original SAC paper (arXiv 1801.01290): Eq 1 for more details.
+            # Default to False.
+            # Note that: Using auto alpha needs to set learning_rate_alpha in `cfg.policy.learn`.
+            auto_alpha=True,
+            # (bool type) log_space: Determine whether to use auto `\alpha` in log space.
+            log_space=True,
+            # (bool) Whether ignore done(usually for max step termination env. e.g. pendulum)
+            # Note: Gym wraps the MuJoCo envs by default with TimeLimit environment wrappers.
+            # These limit HalfCheetah, and several other MuJoCo envs, to max length of 1000.
+            # However, interaction with HalfCheetah always gets done with False,
+            # Since we inplace done==True with done==False to keep
+            # TD-error accurate computation(``gamma * (1 - done) * next_v + reward``),
+            # when the episode step is greater than max episode step.
+            ignore_done=False,
+            # (float) Weight uniform initialization range in the last output layer
+            init_w=3e-3,
+        ),
+        collect=dict(
+            # If you need the data collected by the collector to contain logit key which reflect the probability of
+            # the action, you can change the key to be True.
+            # In Guided cost Learning, we need to use logit to train the reward model, we change the key to be True.
+            # Default collector_logit to False.
+            collector_logit=False,
+            # You can use either "n_sample" or "n_episode" in actor.collect.
+            # Get "n_sample" samples per collect.
+            # Default n_sample to 1.
+            n_sample=1,
+            # (int) Cut trajectories into pieces with length "unroll_len".
+            unroll_len=1,
+        ),
+        eval=dict(
+            evaluator=dict(
+                # (int) Evaluate every "eval_freq" training iterations.
+                eval_freq=5000,
+            ),
+        ),
+        other=dict(
+            replay_buffer=dict(
+                # (int type) replay_buffer_size: Max size of replay buffer.
+                replay_buffer_size=1000000,
+                # (int type) max_use: Max use times of one data in the buffer.
+                # Data will be removed once used for too many times.
+                # Default to infinite.
+                # max_use=256,
+            ),
+        ),
+    )
+
+    def _init_learn(self) -> None:
+        r"""
+        Overview:
+            Learn mode init method. Called by ``self.__init__``.
+            Init q, value and policy's optimizers, algorithm config, main and target models.
+        """
+        # Init
+        self._priority = self._cfg.priority
+        self._priority_IS_weight = self._cfg.priority_IS_weight
+        self._value_network = False  # TODO self._cfg.model.value_network
+        self._twin_critic = self._cfg.model.twin_critic
+
+        # Weight Init for the last output layer
+        init_w = self._cfg.learn.init_w
+        self._model.actor[2].mu.weight.data.uniform_(-init_w, init_w)
+        self._model.actor[2].mu.bias.data.uniform_(-init_w, init_w)
+        self._model.actor[2].log_sigma_layer.weight.data.uniform_(-init_w, init_w)
+        self._model.actor[2].log_sigma_layer.bias.data.uniform_(-init_w, init_w)
+
+        # Optimizers
+        if self._value_network:
+            self._optimizer_value = Adam(
+                self._model.value_critic.parameters(),
+                lr=self._cfg.learn.learning_rate_value,
+            )
+        self._optimizer_q = Adam(
+            self._model.critic.parameters(),
+            lr=self._cfg.learn.learning_rate_q,
+        )
+        self._optimizer_policy = Adam(
+            self._model.actor.parameters(),
+            lr=self._cfg.learn.learning_rate_policy,
+        )
+
+        # Algorithm config
+        self._gamma = self._cfg.learn.discount_factor
+        # Init auto alpha
+        if self._cfg.learn.auto_alpha:
+            self._target_entropy = self._cfg.learn.get('target_entropy', -np.prod(self._cfg.model.action_shape))
+            if self._cfg.learn.log_space:
+                self._log_alpha = torch.log(torch.FloatTensor([self._cfg.learn.alpha]))
+                self._log_alpha = self._log_alpha.to(self._device).requires_grad_()
+                self._alpha_optim = torch.optim.Adam([self._log_alpha], lr=self._cfg.learn.learning_rate_alpha)
+                assert self._log_alpha.shape == torch.Size([1]) and self._log_alpha.requires_grad
+                self._alpha = self._log_alpha.detach().exp()
+                self._auto_alpha = True
+                self._log_space = True
+            else:
+                self._alpha = torch.FloatTensor([self._cfg.learn.alpha]).to(self._device).requires_grad_()
+                self._alpha_optim = torch.optim.Adam([self._alpha], lr=self._cfg.learn.learning_rate_alpha)
+                self._auto_alpha = True
+                self._log_space = False
+        else:
+            self._alpha = torch.tensor(
+                [self._cfg.learn.alpha], requires_grad=False, device=self._device, dtype=torch.float32
+            )
+            self._auto_alpha = False
+
+        # Main and target models
+        self._target_model = copy.deepcopy(self._model)
+        self._target_model = model_wrap(
+            self._target_model,
+            wrapper_name='target',
+            update_type='momentum',
+            update_kwargs={'theta': self._cfg.learn.target_theta}
+        )
+        self._learn_model = model_wrap(self._model, wrapper_name='base')
+        self._learn_model.reset()
+        self._target_model.reset()
+
+        self._forward_learn_cnt = 0
+        # monitor cossimilarity and entropy switch
+        self._monitor_cos = True
+        self._monitor_entropy = True
+
+    def _forward_learn(self, data: dict) -> Dict[str, Any]:
+        """
+        Overview:
+            Forward and backward function of learn mode.
+        Arguments:
+            - data (:obj:`dict`): Dict type data, including at least ['obs', 'action', 'reward', 'next_obs']
+        Returns:
+            - info_dict (:obj:`Dict[str, Any]`): Including current lr, loss, target_q_value and other \
+                running information.
+        """
+        loss_dict = {}
+        data = default_preprocess_learn(
+            data,
+            use_priority=self._priority,
+            use_priority_IS_weight=self._cfg.priority_IS_weight,
+            ignore_done=self._cfg.learn.ignore_done,
+            use_nstep=False
+        )
+        if self._cuda:
+            data = to_device(data, self._device)
+        if self._monitor_cos:
+            agent_data = default_preprocess_learn(
+                data[0:len(data) // 2],
+                use_priority=self._priority,
+                use_priority_IS_weight=self._cfg.priority_IS_weight,
+                ignore_done=self._cfg.learn.ignore_done,
+                use_nstep=False
+            )
+
+            expert_data = default_preprocess_learn(
+                data[len(data) // 2:],
+                use_priority=self._priority,
+                use_priority_IS_weight=self._cfg.priority_IS_weight,
+                ignore_done=self._cfg.learn.ignore_done,
+                use_nstep=False
+            )
+            if self._cuda:
+                agent_data = to_device(agent_data, self._device)
+                expert_data = to_device(expert_data, self._device)
+
+        self._learn_model.train()
+        self._target_model.train()
+        obs = data['obs']
+        next_obs = data['next_obs']
+        reward = data['reward']
+        done = data['done']
+
+        # 1. predict q value
+        q_value = self._learn_model.forward(data, mode='compute_critic')['q_value']
+
+        # 2. predict target value depend self._value_network.
+        if self._value_network:
+            v_value = self._learn_model.forward(obs, mode='compute_value_critic')['v_value']
+            with torch.no_grad():
+                next_v_value = self._target_model.forward(next_obs, mode='compute_value_critic')['v_value']
+            target_q_value = next_v_value
+        else:
+            # target q value.
+            with torch.no_grad():
+                (mu, sigma) = self._learn_model.forward(next_obs, mode='compute_actor')['logit']
+                dist = Independent(Normal(mu, sigma), 1)
+                pred = dist.rsample()
+                next_action = torch.tanh(pred)
+                y = 1 - next_action.pow(2) + 1e-6
+                # keep dimension for loss computation (usually for action space is 1 env. e.g. pendulum)
+                next_log_prob = dist.log_prob(pred).unsqueeze(-1)
+                next_log_prob = next_log_prob - torch.log(y).sum(-1, keepdim=True)
+
+                next_data = {'obs': next_obs, 'action': next_action}
+                target_q_value = self._target_model.forward(next_data, mode='compute_critic')['q_value']
+                # the value of a policy according to the maximum entropy objective
+                if self._twin_critic:
+                    # find min one as target q value
+                    target_q_value = torch.min(target_q_value[0],
+                                               target_q_value[1]) - self._alpha * next_log_prob.squeeze(-1)
+                else:
+                    target_q_value = target_q_value - self._alpha * next_log_prob.squeeze(-1)
+
+        # 3. compute q loss
+        if self._twin_critic:
+            q_data0 = v_1step_td_data(q_value[0], target_q_value, reward, done, data['weight'])
+            loss_dict['critic_loss'], td_error_per_sample0 = v_1step_td_error(q_data0, self._gamma)
+            q_data1 = v_1step_td_data(q_value[1], target_q_value, reward, done, data['weight'])
+            loss_dict['twin_critic_loss'], td_error_per_sample1 = v_1step_td_error(q_data1, self._gamma)
+            td_error_per_sample = (td_error_per_sample0 + td_error_per_sample1) / 2
+        else:
+            q_data = v_1step_td_data(q_value, target_q_value, reward, done, data['weight'])
+            loss_dict['critic_loss'], td_error_per_sample = v_1step_td_error(q_data, self._gamma)
+
+        # 4. update q network
+        self._optimizer_q.zero_grad()
+        loss_dict['critic_loss'].backward()
+        if self._twin_critic:
+            loss_dict['twin_critic_loss'].backward()
+        self._optimizer_q.step()
+
+        # 5. evaluate to get action distribution
+        if self._monitor_cos:
+            # agent
+            (mu, sigma) = self._learn_model.forward(agent_data['obs'], mode='compute_actor')['logit']
+            dist = Independent(Normal(mu, sigma), 1)
+            pred = dist.rsample()
+            action = torch.tanh(pred)
+            y = 1 - action.pow(2) + 1e-6
+            # keep dimension for loss computation (usually for action space is 1 env. e.g. pendulum)
+            agent_log_prob = dist.log_prob(pred).unsqueeze(-1)
+            agent_log_prob = agent_log_prob - torch.log(y).sum(-1, keepdim=True)
+
+            eval_data = {'obs': agent_data['obs'], 'action': action}
+            agent_new_q_value = self._learn_model.forward(eval_data, mode='compute_critic')['q_value']
+            if self._twin_critic:
+                agent_new_q_value = torch.min(agent_new_q_value[0], agent_new_q_value[1])
+            # expert
+            (mu, sigma) = self._learn_model.forward(expert_data['obs'], mode='compute_actor')['logit']
+            dist = Independent(Normal(mu, sigma), 1)
+            pred = dist.rsample()
+            action = torch.tanh(pred)
+            y = 1 - action.pow(2) + 1e-6
+            # keep dimension for loss computation (usually for action space is 1 env. e.g. pendulum)
+            expert_log_prob = dist.log_prob(pred).unsqueeze(-1)
+            expert_log_prob = expert_log_prob - torch.log(y).sum(-1, keepdim=True)
+
+            eval_data = {'obs': expert_data['obs'], 'action': action}
+            expert_new_q_value = self._learn_model.forward(eval_data, mode='compute_critic')['q_value']
+            if self._twin_critic:
+                expert_new_q_value = torch.min(expert_new_q_value[0], expert_new_q_value[1])
+
+        # all data
+        (mu, sigma) = self._learn_model.forward(data['obs'], mode='compute_actor')['logit']
+        dist = Independent(Normal(mu, sigma), 1)
+        # for monitor the entropy of policy
+        if self._monitor_entropy:
+            dist_entropy = dist.entropy()
+            entropy = dist_entropy.mean()
+
+        pred = dist.rsample()
+        action = torch.tanh(pred)
+        y = 1 - action.pow(2) + 1e-6
+        # keep dimension for loss computation (usually for action space is 1 env. e.g. pendulum)
+        log_prob = dist.log_prob(pred).unsqueeze(-1)
+        log_prob = log_prob - torch.log(y).sum(-1, keepdim=True)
+
+        eval_data = {'obs': obs, 'action': action}
+        new_q_value = self._learn_model.forward(eval_data, mode='compute_critic')['q_value']
+        if self._twin_critic:
+            new_q_value = torch.min(new_q_value[0], new_q_value[1])
+
+        # 6. (optional) compute value loss and update value network
+        if self._value_network:
+            # new_q_value: (bs, ), log_prob: (bs, act_shape) -> target_v_value: (bs, )
+            target_v_value = (new_q_value.unsqueeze(-1) - self._alpha * log_prob).mean(dim=-1)
+            loss_dict['value_loss'] = F.mse_loss(v_value, target_v_value.detach())
+
+            # update value network
+            self._optimizer_value.zero_grad()
+            loss_dict['value_loss'].backward()
+            self._optimizer_value.step()
+
+        # 7. compute policy loss
+        policy_loss = (self._alpha * log_prob - new_q_value.unsqueeze(-1)).mean()
+        loss_dict['policy_loss'] = policy_loss
+
+        # 8. update policy network
+        if self._monitor_cos:
+            agent_policy_loss = (self._alpha * agent_log_prob - agent_new_q_value.unsqueeze(-1)).mean()
+            expert_policy_loss = (self._alpha * expert_log_prob - expert_new_q_value.unsqueeze(-1)).mean()
+            loss_dict['agent_policy_loss'] = agent_policy_loss
+            loss_dict['expert_policy_loss'] = expert_policy_loss
+            self._optimizer_policy.zero_grad()
+            loss_dict['agent_policy_loss'].backward()
+            agent_grad = (list(list(self._learn_model.actor.children())[-1].children())[-1].weight.grad).mean()
+            self._optimizer_policy.zero_grad()
+            loss_dict['expert_policy_loss'].backward()
+            expert_grad = (list(list(self._learn_model.actor.children())[-1].children())[-1].weight.grad).mean()
+            cos = nn.CosineSimilarity(dim=0)
+            cos_similarity = cos(agent_grad, expert_grad)
+        self._optimizer_policy.zero_grad()
+        loss_dict['policy_loss'].backward()
+        self._optimizer_policy.step()
+
+        # 9. compute alpha loss
+        if self._auto_alpha:
+            if self._log_space:
+                log_prob = log_prob + self._target_entropy
+                loss_dict['alpha_loss'] = -(self._log_alpha * log_prob.detach()).mean()
+
+                self._alpha_optim.zero_grad()
+                loss_dict['alpha_loss'].backward()
+                self._alpha_optim.step()
+                self._alpha = self._log_alpha.detach().exp()
+            else:
+                log_prob = log_prob + self._target_entropy
+                loss_dict['alpha_loss'] = -(self._alpha * log_prob.detach()).mean()
+
+                self._alpha_optim.zero_grad()
+                loss_dict['alpha_loss'].backward()
+                self._alpha_optim.step()
+                self._alpha = max(0, self._alpha)
+
+        loss_dict['total_loss'] = sum(loss_dict.values())
+
+        # =============
+        # after update
+        # =============
+        self._forward_learn_cnt += 1
+        # target update
+        self._target_model.update(self._learn_model.state_dict())
+        var_monitor = {
+            'cur_lr_q': self._optimizer_q.defaults['lr'],
+            'cur_lr_p': self._optimizer_policy.defaults['lr'],
+            'priority': td_error_per_sample.abs().tolist(),
+            'td_error': td_error_per_sample.detach().mean().item(),
+            'agent_td_error': td_error_per_sample.detach().chunk(2, dim=0)[0].mean().item(),
+            'expert_td_error': td_error_per_sample.detach().chunk(2, dim=0)[1].mean().item(),
+            'alpha': self._alpha.item(),
+            'target_q_value': target_q_value.detach().mean().item(),
+            'mu': mu.detach().mean().item(),
+            'sigma': sigma.detach().mean().item(),
+            'q_value0': new_q_value[0].detach().mean().item(),
+            'q_value1': new_q_value[1].detach().mean().item(),
+            **loss_dict,
+        }
+        if self._monitor_cos:
+            var_monitor['cos_similarity'] = cos_similarity.item()
+        if self._monitor_entropy:
+            var_monitor['entropy'] = entropy.item()
+        return var_monitor
+
+    def _monitor_vars_learn(self) -> List[str]:
+        r"""
+        Overview:
+            Return variables' name if variables are to used in monitor.
+        Returns:
+            - vars (:obj:`List[str]`): Variables' name list.
+        """
+        twin_critic = ['twin_critic_loss'] if self._twin_critic else []
+        alpha_loss = ['alpha_loss'] if self._auto_alpha else []
+        value_loss = ['value_loss'] if self._value_network else []
+        cos_similarity = ['cos_similarity'] if self._monitor_cos else []
+        entropy = ['entropy'] if self._monitor_entropy else []
+        return [
+            'alpha_loss',
+            'policy_loss',
+            'critic_loss',
+            'cur_lr_q',
+            'cur_lr_p',
+            'target_q_value',
+            'alpha',
+            'td_error',
+            'agent_td_error',
+            'expert_td_error',
+            'mu',
+            'sigma',
+            'q_value0',
+            'q_value1',
+        ] + twin_critic + alpha_loss + value_loss + cos_similarity + entropy
