@@ -3,8 +3,7 @@ import time
 import gym
 import numpy as np
 
-from ding.envs import BaseEnv, BaseEnvTimestep, BaseEnvInfo
-from ding.envs.common.env_element import EnvElement, EnvElementInfo
+from ding.envs import BaseEnv, BaseEnvTimestep
 from ding.torch_utils import to_ndarray
 
 from ding.worker.collector.tests.speed_test.utils import random_change
