@@ -10,6 +10,7 @@ pong_ppo_rnd_config = dict(
         evaluator_env_num=evaluator_env_num,
         n_evaluator_episode=evaluator_env_num,
         env_id='PongNoFrameskip-v4',
+        obs_plus_prev_action_reward=True,  # use specific env wrapper for ngu policy
         stop_value=20,
         frame_stack=4,
     ),
@@ -19,7 +20,7 @@ pong_ppo_rnd_config = dict(
         obs_shape=[4, 84, 84],
         action_shape=6,
         batch_size=320,
-        update_per_collect=int(10),  # 32*100/64=50
+        update_per_collect=10,
         only_use_last_five_frames_for_icm_rnd=False,
         clear_buffer_per_iters=10,
         nstep=nstep,
@@ -27,12 +28,26 @@ pong_ppo_rnd_config = dict(
         type='rnd-ngu',
     ),
     episodic_reward_model=dict(
+        # means if using rescale trick to the last non-zero reward
+        # when combing extrinsic and intrinsic reward.
+        # the rescale trick only used in:
+        # 1. sparse reward env minigrid, in which the last non-zero reward is a strong positive signal
+        # 2. the last reward of each episode directly reflects the agent's completion of the task, e.g. lunarlander
+        # Note that the ngu intrinsic reward is a positive value (max value is 5), in these envs,
+        # the last non-zero reward should not be overwhelmed by intrinsic rewards, so we need rescale the
+        # original last nonzero extrinsic reward.
+        # please refer to ngu_reward_model for details.
+        last_nonzero_reward_rescale=False,
+        # means the rescale value for the last non-zero reward, only used when last_nonzero_reward_rescale is True
+        # please refer to ngu_reward_model for details.
+        last_nonzero_reward_weight=1,
+
         intrinsic_reward_type='add',
         learning_rate=1e-4,
         obs_shape=[4, 84, 84],
         action_shape=6,
         batch_size=320,
-        update_per_collect=int(10),  # 32*100/64=50
+        update_per_collect=10,
         only_use_last_five_frames_for_icm_rnd=False,
         clear_buffer_per_iters=10,
         nstep=nstep,
@@ -45,9 +60,12 @@ pong_ppo_rnd_config = dict(
         priority=True,
         priority_IS_weight=True,
         discount_factor=0.997,
-        burnin_step=2,
         nstep=nstep,
-        unroll_len=40,
+        burnin_step=2,
+        # (int) <learn_unroll_len> is the total length of [sequence sample] minus
+        # the length of burnin part in [sequence sample],
+        # i.e., <sequence sample length> = <unroll_len> = <burnin_step> + <learn_unroll_len>
+        learn_unroll_len=40,  # set this key according to the episode length
         model=dict(
             obs_shape=[4, 84, 84],
             action_shape=6,
@@ -61,8 +79,14 @@ pong_ppo_rnd_config = dict(
             target_update_theta=0.001,
         ),
         collect=dict(
-            # NOTE it is important that don't include key n_sample here, to make sure self._traj_len=INF
-            each_iter_n_sample=32,
+            # NOTE: It is important that set key traj_len_inf=True here,
+            # to make sure self._traj_len=INF in serial_sample_collector.py.
+            # In sequence-based policy, for each collect_env,
+            # we want to collect data of length self._traj_len=INF
+            # unless the episode enters the 'done' state.
+            # In each collect phase, we collect a total of <n_sample> sequence samples.
+            n_sample=32,
+            traj_len_inf=True,
             env_num=collector_env_num,
         ),
         eval=dict(env_num=evaluator_env_num, ),
@@ -94,11 +118,13 @@ pong_ppo_rnd_create_config = dict(
     policy=dict(type='ngu'),
     rnd_reward_model=dict(type='rnd-ngu'),
     episodic_reward_model=dict(type='episodic'),
-    collector=dict(type='sample_ngu', )
 )
 pong_ppo_rnd_create_config = EasyDict(pong_ppo_rnd_create_config)
 create_config = pong_ppo_rnd_create_config
 
+
 if __name__ == "__main__":
+    # or you can enter `ding -m serial_ngu -c pong_ngu_config.py -s 0`
     from ding.entry import serial_pipeline_ngu
     serial_pipeline_ngu([main_config, create_config], seed=0)
+
