@@ -1,14 +1,12 @@
 from easydict import EasyDict
-from ding.entry import serial_pipeline
 
 lunarlander_ppo_config = dict(
-    exp_name='lunarlander_ppo_offpolicy',
+    exp_name='lunarlander_offppo_seed0',
     env=dict(
-        manager=dict(shared_memory=True, reset_inplace=True),
         collector_env_num=8,
-        evaluator_env_num=5,
+        evaluator_env_num=8,
         env_id='LunarLander-v2',
-        n_evaluator_episode=5,
+        n_evaluator_episode=8,
         stop_value=200,
     ),
     policy=dict(
@@ -50,4 +48,6 @@ lunarlander_ppo_create_config = EasyDict(lunarlander_ppo_create_config)
 create_config = lunarlander_ppo_create_config
 
 if __name__ == "__main__":
+    # or you can enter `ding -m serial -c lunarlander_offppo_config.py -s 0`
+    from ding.entry import serial_pipeline
     serial_pipeline([main_config, create_config], seed=0)
