@@ -30,18 +30,23 @@ lunarlander_r2d2_config = dict(
         unroll_len=40,
         learn=dict(
             # according to the R2D2 paper, actor parameter update interval is 400
-            # environment timesteps, and in per collect phase, we collect 32 sequence
-            # samples, the length of each sample sequence is <burnin_step> + <unroll_len>,
-            # which is 100 in our seeting, 32*100/400=8, so we set update_per_collect=8
-            # in most environments
+            # environment timesteps, and in per collect phase, we collect <n_sample> sequence
+            # samples, the length of each sequence sample is <burnin_step> + <learn_unroll_len>,
+            # e.g. if  n_sample=32, <sequence length> is 100, thus 32*100/400=8,
+            # we will set update_per_collect=8 in most environments.
             update_per_collect=8,
             batch_size=64,
             learning_rate=0.0005,
             target_update_theta=0.001,
         ),
         collect=dict(
-            # NOTE it is important that don't include key n_sample here, to make sure self._traj_len=INF
-            each_iter_n_sample=32,
+            # NOTE: It is important that set key traj_len_inf=True here,
+            # to make sure self._traj_len=INF in serial_sample_collector.py.
+            # In R2D2 policy, for each collect_env, we want to collect data of length self._traj_len=INF
+            # unless the episode enters the 'done' state.
+            # In each collect phase, we collect a total of <n_sample> sequence samples.
+            n_sample=32,
+            traj_len_inf=True,
             env_num=collector_env_num,
         ),
         eval=dict(env_num=evaluator_env_num, ),
