@@ -2,9 +2,9 @@ import argparse
 import torch
 from ding.entry import trex_collecting_data
 from dizoo.mujoco.config.halfcheetah_trex_onppo_default_config import main_config, create_config
-from ding.entry import serial_pipeline_reward_model_trex_onpolicy, serial_pipeline_reward_model_trex
+from ding.entry import serial_pipeline_trex_onpolicy, serial_pipeline_trex
 
-# Note serial_pipeline_reward_model_trex_onpolicy is for on policy ppo whereas serial_pipeline_reward_model_trex is for sac
+# Note serial_pipeline_trex_onpolicy is for on policy ppo whereas serial_pipeline_trex is for sac
 # Note before run this file, please add the correpsonding path in the config, all path expect exp_name should be abs path
 
 parser = argparse.ArgumentParser()
@@ -18,5 +18,5 @@ parser.add_argument('--device', type=str, default='cuda' if torch.cuda.is_availa
 args = parser.parse_args()
 
 trex_collecting_data(args)
-# if run sac, please import the relevant config and use serial_pipeline_reward_model_trex
-serial_pipeline_reward_model_trex_onpolicy([main_config, create_config])
+# if run sac, please import the relevant config and use serial_pipeline_trex
+serial_pipeline_trex_onpolicy([main_config, create_config])
